@@ -13,6 +13,8 @@ if [ ! -d $DOMAIN_ROOT/$DOMAIN ]; then
    $BASEDIR/bin/asadmin create-domain --domaindir $DOMAIN_ROOT --adminport $ADMIN_PORT --adminuser $ADMIN_USER --passwordfile $PASSWORD_FILE --instanceport $INSTANCE_PORT $DOMAIN   
    result=$?
    if [ $result -ne 0 ]; then
+      echo "Could not create default domain $DOMAIN at $DOMAIN_ROOT.\n"
+      echo "Create required domains manually using asadmin \n"
       exit 1
    fi
 fi
